@@ -20,7 +20,9 @@ describe 'trove::policy' do
         :key   => 'context_is_admin',
         :value => 'foo:bar'
       })
-      is_expected.to contain_trove_config('oslo_policy/policy_file').with_value('/etc/trove/policy.json')
+      is_expected.to contain_oslo__policy('trove_config').with(
+        :policy_file => '/etc/trove/policy.json',
+      )
     end
   end
 
