@@ -51,34 +51,44 @@ describe 'trove::taskmanager' do
       end
 
       it 'configures trove-taskmanager with default parameters' do
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/use_syslog').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/syslog_log_facility').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/log_file').with_value('/var/log/trove/trove-taskmanager.log')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/log_dir').with_value('/var/log/trove')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_proxy_admin_user').with_value('admin')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_proxy_admin_pass').with_value('verysecrete')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_proxy_admin_tenant_name').with_value('admin')
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/default_neutron_networks').with_value(nil)
-        is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_value(nil)
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/default_neutron_networks').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/os_region_name').with_value('RegionOne')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/nova_compute_service_type').with_value('compute')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/cinder_service_type').with_value('volume')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/swift_service_type').with_value('object-store')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/heat_service_type').with_value('orchestration')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/neutron_service_type').with_value('network')
-        is_expected.to contain_trove_config('DEFAULT/taskmanager_queue').with_value('taskmanager')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/taskmanager_manager').with_value('trove.taskmanager.manager.Manager')
         is_expected.to contain_file('/etc/trove/trove-guestagent.conf')
         is_expected.to contain_trove_taskmanager_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/control_exchange').with_value('trove')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_nova_client').with_ensure('absent')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_cinder_client').with_ensure('absent')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_neutron_client').with_ensure('absent')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_notifications/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_notifications/topics').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_taskmanager_config').with(
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
+        )
+      end
+
+      it 'configures trove-taskmanager with default logging parameters' do
+        is_expected.to contain_oslo__log('trove_taskmanager_config').with(
+          :use_syslog          => '<SERVICE DEFAULT>',
+          :syslog_log_facility => '<SERVICE DEFAULT>',
+          :log_dir             => '/var/log/trove',
+          :log_file            => '/var/log/trove/trove-taskmanager.log',
+          :debug               => '<SERVICE DEFAULT>',
+        )
       end
 
       context 'when set use_guestagent_template to false' do
@@ -96,6 +106,22 @@ describe 'trove::taskmanager' do
         end
       end
 
+      context 'with single tenant mode enabled' do
+        let :pre_condition do
+          "class { 'trove':
+             nova_proxy_admin_pass => 'verysecrete',
+             single_tenant_mode    => 'true'}
+           class { '::trove::keystone::authtoken':
+             password => 'a_big_secret',
+           }"
+        end
+        it 'single tenant client values are set' do
+          is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_nova_client').with_value('trove.common.single_tenant_remote.nova_client_trove_admin')
+          is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_cinder_client').with_value('trove.common.single_tenant_remote.cinder_client_trove_admin')
+          is_expected.to contain_trove_taskmanager_config('DEFAULT/remote_neutron_client').with_value('trove.common.single_tenant_remote.neutron_client_trove_admin')
+        end
+      end
+
       context 'when using a single RabbitMQ server' do
         let :pre_condition do
           "class { 'trove':
@@ -175,15 +201,12 @@ describe 'trove::taskmanager' do
         end
 
         it 'configures trove to use the Neutron network driver' do
-          is_expected.to contain_trove_config('DEFAULT/default_neutron_networks').with_value('trove_service')
           is_expected.to contain_trove_taskmanager_config('DEFAULT/default_neutron_networks').with_value('trove_service')
-          is_expected.to contain_trove_config('DEFAULT/network_driver').with_value('trove.network.neutron.NeutronDriver')
           is_expected.to contain_trove_taskmanager_config('DEFAULT/network_driver').with_value('trove.network.neutron.NeutronDriver')
 
         end
 
         it 'configures trove to use any network label' do
-          is_expected.to contain_trove_config('DEFAULT/network_label_regex').with_value('.*')
           is_expected.to contain_trove_taskmanager_config('DEFAULT/network_label_regex').with_value('.*')
         end
       end
@@ -197,13 +220,11 @@ describe 'trove::taskmanager' do
         end
 
         it 'configures trove to use the Nova Network network driver' do
-          is_expected.to contain_trove_config('DEFAULT/network_driver').with_value('trove.network.nova.NovaNetwork')
+          is_expected.to contain_trove_taskmanager_config('DEFAULT/default_neutron_networks').with_ensure('absent')
           is_expected.to contain_trove_taskmanager_config('DEFAULT/network_driver').with_value('trove.network.nova.NovaNetwork')
-
         end
 
         it 'configures trove to use the "private" network label' do
-          is_expected.to contain_trove_config('DEFAULT/network_label_regex').with_value('^private$')
           is_expected.to contain_trove_taskmanager_config('DEFAULT/network_label_regex').with_value('^private$')
         end
       end
@@ -220,11 +241,13 @@ describe 'trove::taskmanager' do
       end
 
       it do
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
+        is_expected.to contain_oslo__messaging__rabbit('trove_taskmanager_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '/path/to/ssl/ca/certs',
+          :kombu_ssl_certfile => '/path/to/ssl/cert/file',
+          :kombu_ssl_keyfile  => '/path/to/ssl/keyfile',
+          :kombu_ssl_version  => 'TLSv1',
+        )
       end
     end
 
@@ -232,15 +255,17 @@ describe 'trove::taskmanager' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => true}"
+           rabbit_use_ssl        => true}"
       end
 
       it do
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_taskmanager_config').with(
+          :rabbit_use_ssl     => true,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
@@ -248,28 +273,34 @@ describe 'trove::taskmanager' do
       let :pre_condition do
         "class { 'trove':
            nova_proxy_admin_pass => 'verysecrete',
-           rabbit_use_ssl     => false}"
+           rabbit_use_ssl        => false}"
       end
 
       it do
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_trove_taskmanager_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('trove_taskmanager_config').with(
+          :rabbit_use_ssl     => false,
+          :kombu_ssl_ca_certs => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile  => '<SERVICE DEFAULT>',
+          :kombu_ssl_version  => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     context 'with transport_url entries' do
       let :pre_condition do
         "class { 'trove':
-           nova_proxy_admin_pass => 'verysecrete',
-           default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+           nova_proxy_admin_pass      => 'verysecrete',
+           default_transport_url      => 'rabbit://rabbit_user:password@localhost:5673',
+           rpc_response_timeout       => '120',
+           control_exchange           => 'openstack',
            notification_transport_url => 'rabbit://rabbit_user:password@localhost:5673' }"
       end
 
       it do
         is_expected.to contain_trove_taskmanager_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/rpc_response_timeout').with_value('120')
+        is_expected.to contain_trove_taskmanager_config('DEFAULT/control_exchange').with_value('openstack')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
       end
     end
@@ -278,11 +309,10 @@ describe 'trove::taskmanager' do
       let :pre_condition do
         "class { 'trove' :
            nova_proxy_admin_pass => 'verysecrete',
-           rpc_backend => 'amqp' }"
+           rpc_backend           => 'amqp' }"
       end
 
       it do
-        is_expected.to contain_trove_taskmanager_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_trove_taskmanager_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
